@@ -10,22 +10,6 @@ function(u,a,s,i,theta0=0,exac=0.001,osch=22, ...)
 
 #ctrl
 co_3PL(u,a,s,i,theta0)
-  
-DELTA_mle <- function(a,s,i,th,u) 
-    {
-		# 3PL model 
-		Zae <- expression(exp(a*(th-s)))
-		P <- i+(1-i) * eval(Zae) / (1+eval(Zae))
-		# shortcuts
-		Emp <- 1-P
-		Pmi <- P-i
-		Emi <- 1-i
-		Wij <- P*(1-P)
-		# put it all together
-		O <-  sum(a*Wij*((u-P)/Wij)*(Pmi/Emi/P))
-		U <-  sum(a^2*Wij*(Pmi/Emi/P)^2) 
-		list(deLt = O/U,InF = U)
-		}
 
 
 count <- 0 
@@ -49,6 +33,7 @@ if(all(u==1))
               SE     <- NA  
   						break
               }
+            
             if(abs(del)>2){del <- del/abs(del) * 2}
             thetan <- theta0 + del
             theta0 <- thetan
